package com.ichaoj.ams.controller;

import cn.hutool.core.util.StrUtil;
import com.ichaoj.ams.request.address.BatchAddressRequest;
import com.ichaoj.ams.request.address.BatchKeyStoreRequest;
import com.ichaoj.ams.request.address.PageAddressRequest;
import com.ichaoj.ams.request.address.PremiumAddressRequest;
import com.ichaoj.ams.response.address.AddressResponse;
import com.ichaoj.ams.service.IAmsAddressAccountService;
import com.ichaoj.common.annotation.AuthResource;
import com.ichaoj.common.exception.ErrorServiceException;
import com.ichaoj.common.model.PublicPage;
import com.ichaoj.common.model.PublicResult;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @author cjwen
 */
@RestController
@RequestMapping("/address")
@Tag(name = "地址模块")
public class AddressController {

    @Resource
    IAmsAddressAccountService addressService;

    @Operation(summary = "批量创建钱包")
    @PostMapping("/generate/batch-address")
    @AuthResource
    public PublicResult<List<String>> batchCreateAddress(@RequestBody @Validated BatchAddressRequest batchAddressRequest) {
        return PublicResult.success(addressService.batchCreateAddress(batchAddressRequest));
    }

    @Operation(summary = "批量下载keystore文件")
    @PostMapping("/download/batch-keystore")
    @AuthResource
    @Validated
    public void batchKeystore(HttpServletResponse response,@RequestBody @Validated BatchKeyStoreRequest keyStoreRequest) {
        addressService.batchKeystore(keyStoreRequest.getGroupName(), response);
    }

    @Operation(summary = "添加精品号")
    @PostMapping("/add/premium-address")
    @AuthResource
    public PublicResult<Object> addPremiumAddress(@RequestBody PremiumAddressRequest addressRequest) {
        if (StrUtil.isBlank(addressRequest.getAddress())) {
            throw new ErrorServiceException("The address cannot be blank");
        }
        addressService.addPremiumAddress(addressRequest);
        return PublicResult.success();
    }

    @Operation(summary = "分页查询地址")
    @PostMapping("/page")
    @AuthResource
    public PublicResult<PublicPage<AddressResponse>> pageAddress(@RequestBody PageAddressRequest pageAddressRequest) {
        PublicPage<AddressResponse> result = addressService.pageAddress(pageAddressRequest);
        return PublicResult.success(result);
    }

    @Operation(summary = "查询地址组列表")
    @GetMapping("/group-list")
    @AuthResource
    public PublicResult<List<String>> queryGroupList() {
        List<String> result = addressService.queryGroupList();
        return PublicResult.success(result);
    }

}
